import { fetchLocalApi } from '@/utils/request';

export const isClient = !!window.ipcRenderer; // process.env.IS_CLIENT;

const noop = () => {};
const safeCall = <T>(f: T, repalceF = noop) => (isClient ? f : repalceF);

const ipcRenderer = window.ipcRenderer;

const system = {
  closeWindow() {
    ipcRenderer.invoke('manipulate-window', { action: 'close' });
  },
  zoomWindow() {
    ipcRenderer.invoke('manipulate-window', { action: 'zoom' });
  },
  minimizeWindow() {
    ipcRenderer.invoke('manipulate-window', { action: 'minimize' });
  },
  openUrl(url: string) {
    if (!isClient) {
      window.open(url, 'blank');
      return;
    }
    ipcRenderer.invoke('open-browser', url);
  },

  storage: {
    set: safeCall((key: string, value: any) => {
      ipcRenderer.invoke('storage:set', { key, value });
    }),
    remove: safeCall((key: string) => {
      ipcRenderer.invoke('storage:remove', { key });
    }),
  },

  // 发往网关的请求
  login: safeCall((userId: string, userPhone: string) => {
    return fetchLocalApi<null>('login', { userId, userPhone });
  }),
};

export default system;
